<template>
    <div class="home-card">
        <div class="card-header">
            <div class="title">
                环境系统
            </div>
            <div class="extend">
                <AIcon type="CaretLeftFilled" style="font-size: 16px; color: #E0E0E0;" />
                <div>湿度传感器1</div>
                <AIcon type="CaretRightFilled" style="font-size: 16px; color: #E0E0E0;" />
            </div>
        </div>
        <div ref="chartParentRef" class="card-content">
            <div class="up-container">
                <div class="item">
                    <img class="image" :src="getImage('/home/h-10.png')" />
                    <div style="margin-left: 10px;">
                        <span style="font-size: 24px; font-weight: bold;color: #333333;">25</span>℃
                        <br>
                        温度
                    </div>
                </div>
                <div class="item">
                    <img class="image" :src="getImage('/home/h-12.png')" />
                    <div style="margin-left: 10px;">
                        <span style="font-size: 24px; font-weight: bold;color: #333333;">25</span>%rh
                        <br>
                        湿度
                    </div>
                </div>
            </div>

            <div ref="chartRef" style="width: 100%; min-height: 200px"></div>
        </div>
    </div>
</template>

<script setup lang="ts" name="EnvironmentSystem">
import { getImage } from '@/utils/comm';
import { useMenuStore } from '@/store/menu';
import * as echarts from 'echarts';

const chartRef = ref<Record<string, any>>({});
const chartParentRef = ref<Record<string, any>>({});
const menu = useMenuStore();
let myChart: any = null;

const handleOptions = (x = [], y = []) => {
    const chart: any = chartRef.value;
    if (chart) {
        myChart = echarts.init(chart);
        const options = {
            title: {
                text: '24小时平均温度'
            },
            legend: {
                top: 20,
                right: 10,
                data: ['温度', '湿度']
            },
            grid: {
                left: '3%',
                right: '4%',
                bottom: '3%',
                containLabel: true
            },
            xAxis: {
                type: 'category',
                data: ['01:00', '03:00', '05:00', '07:00', '09:00', '11:00', '13:00', '15:00', '17:00', '19:00', '21:00', '23:00']
            },
            yAxis: {
                type: 'value'
            },
            series: [
                {
                    name: '温度',
                    data: [14, 15, 16, 17, 19, 20, 22, 25, 26, 25, 23, 18],
                    type: 'line',
                    smooth: true
                },
                {
                    name: '湿度',
                    data: [44, 45, 36, 37, 39, 40, 32, 35, 36, 35, 33, 28],
                    type: 'line',
                    smooth: true
                }
            ]
        };
        nextTick(() => {
            myChart.setOption(options);
            window.addEventListener('resize', function () {
                myChart.resize();
            });
        });
    }
};

watch(() => menu.collapsed, (newX) => {
    setTimeout(() => {
        myChart.resize();
    }, 300);
})

onMounted(() => {
    handleOptions();
})
</script>

<style lang="less" scoped>
.home-card {
    width: 100%;

    .card-content {
        width: 100%;
        padding: 14px;

        .up-container {
            display: flex;
            margin-bottom: 16px;

            .item {
                flex: 1;
                display: flex;
                align-items: center;
                justify-content: center;
                font-size: 14px;
                font-family: PingFang SC-Regular, PingFang SC;
                font-weight: 400;
                color: #828282;
                line-height: 23px;
                .image {
                    width: 56px;
                    height: 56px;
                }
            }
        }
    }
}
</style>
